
#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>
#include <kernel/generic/include/ipc/ipc.h>
#include "all_enums.h"

#define CMDNAME(cmd) \
	"\\texttt{" cmd "}"
#define METHOD(macro) \
	printf("\\ipcmethod{%s}{%4d}\n\n", #macro, macro);
#define INTERFACE(macro) \
	printf("\\ipcinterface{%s}{%2d}\n\n", #macro, macro);
#define IPCGROUP(name) \
	printf("\\ipcgroup{%s}\n", name);
#define IPCSUBGROUP(name) \
	printf("\\ipcsubgroup{%s}\n", name);

#ifdef PRINT_ALL
#define PRINT_SYSTEM
#define PRINT_VFS
#define PRINT_DEVMAN
#define PRINT_DEVMAP
#define PRINT_DRIVERS
#define PRINT_NS
#define PRINT_LOADER
#define PRINT_CONSOLE
#endif


int main(int argc, char *argv[])
{

#ifdef PRINT_SYSTEM
	IPCGROUP("System methods")

	METHOD(IPC_M_CONNECT_TO_ME)
	METHOD(IPC_M_CONNECT_ME_TO)
	METHOD(IPC_M_PHONE_HUNGUP)
	METHOD(IPC_M_SHARE_OUT)
	METHOD(IPC_M_SHARE_IN)
	METHOD(IPC_M_DATA_WRITE)
	METHOD(IPC_M_DATA_READ)
	METHOD(IPC_M_DEBUG_ALL)
	METHOD(IPC_M_LAST_SYSTEM)
	METHOD(IPC_M_PING)
	METHOD(IPC_FIRST_USER_METHOD)
#endif

#ifdef PRINT_VFS
	IPCGROUP("VFS (" CMDNAME("init:vfs") ")")

	IPCSUBGROUP("In requests")
	METHOD(VFS_IN_OPEN)
	METHOD(VFS_IN_OPEN_NODE)
	METHOD(VFS_IN_READ)
	METHOD(VFS_IN_WRITE)
	METHOD(VFS_IN_SEEK)
	METHOD(VFS_IN_TRUNCATE)
	METHOD(VFS_IN_FSTAT)
	METHOD(VFS_IN_CLOSE)
	METHOD(VFS_IN_MOUNT)
	METHOD(VFS_IN_UNMOUNT)
	METHOD(VFS_IN_SYNC)
	METHOD(VFS_IN_REGISTER)
	METHOD(VFS_IN_MKDIR)
	METHOD(VFS_IN_UNLINK)
	METHOD(VFS_IN_RENAME)
	METHOD(VFS_IN_STAT)
	METHOD(VFS_IN_DUP)

	IPCSUBGROUP("Out requests")
	METHOD(VFS_OUT_OPEN_NODE)
	METHOD(VFS_OUT_READ)
	METHOD(VFS_OUT_WRITE)
	METHOD(VFS_OUT_TRUNCATE)
	METHOD(VFS_OUT_CLOSE)
	METHOD(VFS_OUT_MOUNT)
	METHOD(VFS_OUT_MOUNTED)
	METHOD(VFS_OUT_UNMOUNT)
	METHOD(VFS_OUT_UNMOUNTED)
	METHOD(VFS_OUT_SYNC)
	METHOD(VFS_OUT_STAT)
	METHOD(VFS_OUT_LOOKUP)
	METHOD(VFS_OUT_DESTROY)
	METHOD(VFS_OUT_LAST)
#endif


#ifdef PRINT_DEVMAN
	IPCGROUP("Device manager (" CMDNAME("devman") ")");

	IPCSUBGROUP("Devman to driver");
	METHOD(DRIVER_ADD_DEVICE);

	IPCSUBGROUP("Driver to devman");
	METHOD(DEVMAN_DRIVER_REGISTER)
	METHOD(DEVMAN_ADD_CHILD_DEVICE)
	METHOD(DEVMAN_ADD_MATCH_ID)
	METHOD(DEVMAN_ADD_DEVICE_TO_CLASS)
#endif


#ifdef PRINT_DRIVERS
	IPCGROUP("Drivers")

	IPCSUBGROUP("Driver interfaces")
	INTERFACE(DEVMAN_DRIVER)
	INTERFACE(DEVMAN_CLIENT)
	INTERFACE(DEVMAN_CONNECT_TO_DEVICE)
	INTERFACE(DEVMAN_CONNECT_FROM_DEVMAP)
	INTERFACE(DEVMAN_CONNECT_TO_PARENTS_DEVICE)
#endif



#ifdef PRINT_DEVMAP
	IPCGROUP("Device mapper (" CMDNAME("init:devmap") ")")
	METHOD(DEVMAP_DRIVER_REGISTER)
	METHOD(DEVMAP_DRIVER_UNREGISTER)
	METHOD(DEVMAP_DEVICE_REGISTER)
	METHOD(DEVMAP_DEVICE_UNREGISTER)
	METHOD(DEVMAP_DEVICE_GET_HANDLE)
	METHOD(DEVMAP_NAMESPACE_GET_HANDLE)
	METHOD(DEVMAP_HANDLE_PROBE)
	METHOD(DEVMAP_NULL_CREATE)
	METHOD(DEVMAP_NULL_DESTROY)
	METHOD(DEVMAP_GET_NAMESPACE_COUNT)
	METHOD(DEVMAP_GET_DEVICE_COUNT)
	METHOD(DEVMAP_GET_NAMESPACES)
	METHOD(DEVMAP_GET_DEVICES)

	IPCSUBGROUP("Devmap interfaces")
	INTERFACE(DEVMAP_DRIVER)
	INTERFACE(DEVMAP_CLIENT)
	INTERFACE(DEVMAP_CONNECT_TO_DEVICE)
#endif


#ifdef PRINT_NS
	IPCGROUP("Naming service (" CMDNAME("init:ns") ")" )
	METHOD(NS_PING)
	METHOD(NS_TASK_WAIT)
	METHOD(NS_ID_INTRO)
	METHOD(NS_RETVAL)
#endif


#ifdef PRINT_LOADER
	IPCGROUP("Task loader")
	METHOD(LOADER_HELLO)
	METHOD(LOADER_GET_TASKID)
	METHOD(LOADER_SET_CWD)
	METHOD(LOADER_SET_PATHNAME)
	METHOD(LOADER_SET_ARGS)
	METHOD(LOADER_SET_FILES)
	METHOD(LOADER_LOAD)
	METHOD(LOADER_RUN)
#endif


#ifdef PRINT_CONSOLE
	IPCGROUP("Userspace console")
	METHOD(CONSOLE_GET_SIZE)
	METHOD(CONSOLE_GET_COLOR_CAP)
	METHOD(CONSOLE_GET_EVENT)
	METHOD(CONSOLE_GET_POS)
	METHOD(CONSOLE_GOTO)
	METHOD(CONSOLE_CLEAR)
	METHOD(CONSOLE_SET_STYLE)
	METHOD(CONSOLE_SET_COLOR)
	METHOD(CONSOLE_SET_RGB_COLOR)
	METHOD(CONSOLE_CURSOR_VISIBILITY)
	METHOD(CONSOLE_KCON_ENABLE)
#endif

	return 0;
}

